@@ -1,12 +1,24 @@
-from pm4py.objects.conversion.log import factory as log_conv_factory
+from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.objects.log.log import EventLog
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY, DEFAULT_RESOURCE_KEY, DEFAULT_TIMESTAMP_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_ATTRIBUTE_KEY, PARAMETER_CONSTANT_RESOURCE_KEY, \
     PARAMETER_CONSTANT_TIMESTAMP_KEY
+from enum import Enum
+from pm4py.util import exec_utils
 
-POSITIVE = "positive"
-ENABLE_TIMESTAMP = "enable_timestamp"
-TIMESTAMP_DIFF_BOUNDARIES = "timestamp_diff_boundaries"
+
+class Parameters(Enum):
+    ATTRIBUTE_KEY = PARAMETER_CONSTANT_ATTRIBUTE_KEY
+    TIMESTAMP_KEY = PARAMETER_CONSTANT_TIMESTAMP_KEY
+    RESOURCE_KEY = PARAMETER_CONSTANT_RESOURCE_KEY
+    POSITIVE = "positive"
+    ENABLE_TIMESTAMP = "enable_timestamp"
+    TIMESTAMP_DIFF_BOUNDARIES = "timestamp_diff_boundaries"
+
+
+POSITIVE = Parameters.POSITIVE
+ENABLE_TIMESTAMP = Parameters.ENABLE_TIMESTAMP
+TIMESTAMP_DIFF_BOUNDARIES = Parameters.TIMESTAMP_DIFF_BOUNDARIES
 
 
 def timestamp_list_is_ge(a, b):
@@ -50,15 +62,13 @@ def A_eventually_B(log, A, B, parameters=None):
         parameters = {}
 
     if not isinstance(log, EventLog):
-        log = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_LOG, parameters=parameters)
+        log = log_converter.apply(log, variant=log_converter.TO_EVENT_LOG, parameters=parameters)
 
-    attribute_key = parameters[
-        PARAMETER_CONSTANT_ATTRIBUTE_KEY] if PARAMETER_CONSTANT_ATTRIBUTE_KEY in parameters else DEFAULT_NAME_KEY
-    timestamp_key = parameters[
-        PARAMETER_CONSTANT_TIMESTAMP_KEY] if PARAMETER_CONSTANT_TIMESTAMP_KEY in parameters else DEFAULT_TIMESTAMP_KEY
-    positive = parameters[POSITIVE] if POSITIVE in parameters else True
-    enable_timestamp = parameters[ENABLE_TIMESTAMP] if ENABLE_TIMESTAMP in parameters else False
-    timestamp_diff_boundaries = parameters[TIMESTAMP_DIFF_BOUNDARIES] if TIMESTAMP_DIFF_BOUNDARIES in parameters else []
+    attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
+    enable_timestamp = exec_utils.get_param_value(Parameters.ENABLE_TIMESTAMP, parameters, False)
+    timestamp_diff_boundaries = exec_utils.get_param_value(Parameters.TIMESTAMP_DIFF_BOUNDARIES, parameters, [])
 
     new_log = EventLog()
 
@@ -119,15 +129,13 @@ def A_eventually_B_eventually_C(log, A, B, C, parameters=None):
         parameters = {}
 
     if not isinstance(log, EventLog):
-        log = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_LOG, parameters=parameters)
+        log = log_converter.apply(log, variant=log_converter.TO_EVENT_LOG, parameters=parameters)
 
-    attribute_key = parameters[
-        PARAMETER_CONSTANT_ATTRIBUTE_KEY] if PARAMETER_CONSTANT_ATTRIBUTE_KEY in parameters else DEFAULT_NAME_KEY
-    timestamp_key = parameters[
-        PARAMETER_CONSTANT_TIMESTAMP_KEY] if PARAMETER_CONSTANT_TIMESTAMP_KEY in parameters else DEFAULT_TIMESTAMP_KEY
-    positive = parameters[POSITIVE] if POSITIVE in parameters else True
-    enable_timestamp = parameters[ENABLE_TIMESTAMP] if ENABLE_TIMESTAMP in parameters else False
-    timestamp_diff_boundaries = parameters[TIMESTAMP_DIFF_BOUNDARIES] if TIMESTAMP_DIFF_BOUNDARIES in parameters else []
+    attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
+    enable_timestamp = exec_utils.get_param_value(Parameters.ENABLE_TIMESTAMP, parameters, False)
+    timestamp_diff_boundaries = exec_utils.get_param_value(Parameters.TIMESTAMP_DIFF_BOUNDARIES, parameters, [])
 
     new_log = EventLog()
 
@@ -194,15 +202,13 @@ def A_eventually_B_eventually_C_eventually_D(log, A, B, C, D, parameters=None):
         parameters = {}
 
     if not isinstance(log, EventLog):
-        log = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_LOG, parameters=parameters)
+        log = log_converter.apply(log, variant=log_converter.TO_EVENT_LOG, parameters=parameters)
 
-    attribute_key = parameters[
-        PARAMETER_CONSTANT_ATTRIBUTE_KEY] if PARAMETER_CONSTANT_ATTRIBUTE_KEY in parameters else DEFAULT_NAME_KEY
-    timestamp_key = parameters[
-        PARAMETER_CONSTANT_TIMESTAMP_KEY] if PARAMETER_CONSTANT_TIMESTAMP_KEY in parameters else DEFAULT_TIMESTAMP_KEY
-    positive = parameters[POSITIVE] if POSITIVE in parameters else True
-    enable_timestamp = parameters[ENABLE_TIMESTAMP] if ENABLE_TIMESTAMP in parameters else False
-    timestamp_diff_boundaries = parameters[TIMESTAMP_DIFF_BOUNDARIES] if TIMESTAMP_DIFF_BOUNDARIES in parameters else []
+    attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
+    enable_timestamp = exec_utils.get_param_value(Parameters.ENABLE_TIMESTAMP, parameters, False)
+    timestamp_diff_boundaries = exec_utils.get_param_value(Parameters.TIMESTAMP_DIFF_BOUNDARIES, parameters, [])
 
     new_log = EventLog()
 
@@ -216,17 +222,21 @@ def A_eventually_B_eventually_C_eventually_D(log, A, B, C, D, parameters=None):
                      attribute_key in trace[i] and trace[i][attribute_key] == C]
             occ_D = [trace[i][timestamp_key] for i in range(len(trace)) if
                      attribute_key in trace[i] and trace[i][attribute_key] == D]
-            diffs = [[occ_B[j].timestamp() - occ_A[i].timestamp(), occ_C[z].timestamp() - occ_B[j].timestamp(), occ_D[za].timestamp() - occ_C[z].timestamp()] for i in
+            diffs = [[occ_B[j].timestamp() - occ_A[i].timestamp(), occ_C[z].timestamp() - occ_B[j].timestamp(),
+                      occ_D[za].timestamp() - occ_C[z].timestamp()] for i in
                      range(len(occ_A)) for j in range(len(occ_B))
-                     for z in range(len(occ_C)) for za in range(len(occ_D)) if occ_B[j] > occ_A[i] and occ_C[z] > occ_B[j] and occ_D[za] > occ_C[z]]
+                     for z in range(len(occ_C)) for za in range(len(occ_D)) if
+                     occ_B[j] > occ_A[i] and occ_C[z] > occ_B[j] and occ_D[za] > occ_C[z]]
         else:
             occ_A = [i for i in range(len(trace)) if attribute_key in trace[i] and trace[i][attribute_key] == A]
             occ_B = [i for i in range(len(trace)) if attribute_key in trace[i] and trace[i][attribute_key] == B]
             occ_C = [i for i in range(len(trace)) if attribute_key in trace[i] and trace[i][attribute_key] == C]
             occ_D = [i for i in range(len(trace)) if attribute_key in trace[i] and trace[i][attribute_key] == D]
 
-            diffs = [[occ_B[j] - occ_A[i], occ_C[z] - occ_B[j], occ_D[za] - occ_C[z]] for i in range(len(occ_A)) for j in range(len(occ_B))
-                     for z in range(len(occ_C)) for za in range(len(occ_D)) if occ_B[j] > occ_A[i] and occ_C[z] > occ_B[j] and occ_D[za] > occ_C[z]]
+            diffs = [[occ_B[j] - occ_A[i], occ_C[z] - occ_B[j], occ_D[za] - occ_C[z]] for i in range(len(occ_A)) for j
+                     in range(len(occ_B))
+                     for z in range(len(occ_C)) for za in range(len(occ_D)) if
+                     occ_B[j] > occ_A[i] and occ_C[z] > occ_B[j] and occ_D[za] > occ_C[z]]
 
         if enable_timestamp and timestamp_diff_boundaries:
             diffs = [d for d in diffs if
@@ -271,11 +281,10 @@ def A_next_B_next_C(log, A, B, C, parameters=None):
         parameters = {}
 
     if not isinstance(log, EventLog):
-        log = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_LOG, parameters=parameters)
+        log = log_converter.apply(log, variant=log_converter.TO_EVENT_LOG, parameters=parameters)
 
-    attribute_key = parameters[
-        PARAMETER_CONSTANT_ATTRIBUTE_KEY] if PARAMETER_CONSTANT_ATTRIBUTE_KEY in parameters else DEFAULT_NAME_KEY
-    positive = parameters[POSITIVE] if POSITIVE in parameters else True
+    attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     new_log = EventLog()
 
@@ -329,13 +338,11 @@ def four_eyes_principle(log, A, B, parameters=None):
         parameters = {}
 
     if not isinstance(log, EventLog):
-        log = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_LOG, parameters=parameters)
+        log = log_converter.apply(log, variant=log_converter.TO_EVENT_LOG, parameters=parameters)
 
-    attribute_key = parameters[
-        PARAMETER_CONSTANT_ATTRIBUTE_KEY] if PARAMETER_CONSTANT_ATTRIBUTE_KEY in parameters else DEFAULT_NAME_KEY
-    resource_key = parameters[
-        PARAMETER_CONSTANT_RESOURCE_KEY] if PARAMETER_CONSTANT_RESOURCE_KEY in parameters else DEFAULT_RESOURCE_KEY
-    positive = parameters[POSITIVE] if POSITIVE in parameters else True
+    attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
+    resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, DEFAULT_RESOURCE_KEY)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     new_log = EventLog()
 
@@ -380,13 +387,11 @@ def attr_value_different_persons(log, A, parameters=None):
         parameters = {}
 
     if not isinstance(log, EventLog):
-        log = log_conv_factory.apply(log, variant=log_conv_factory.TO_EVENT_LOG, parameters=parameters)
+        log = log_converter.apply(log, variant=log_converter.TO_EVENT_LOG, parameters=parameters)
 
-    attribute_key = parameters[
-        PARAMETER_CONSTANT_ATTRIBUTE_KEY] if PARAMETER_CONSTANT_ATTRIBUTE_KEY in parameters else DEFAULT_NAME_KEY
-    resource_key = parameters[
-        PARAMETER_CONSTANT_RESOURCE_KEY] if PARAMETER_CONSTANT_RESOURCE_KEY in parameters else DEFAULT_RESOURCE_KEY
-    positive = parameters[POSITIVE] if POSITIVE in parameters else True
+    attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
+    resource_key = exec_utils.get_param_value(Parameters.RESOURCE_KEY, parameters, DEFAULT_RESOURCE_KEY)
+    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     new_log = EventLog()
 
