@@ -22,7 +22,7 @@ def staterep(name):
     return re.sub(r'\W+', '', name)
 
 
-def construct_reachability_graph(net, initial_marking):
+def construct_reachability_graph(net, initial_marking, use_trans_name=False):
     """
     Creates a reachability graph of a certain Petri net.
     DO NOT ATTEMPT WITH AN UNBOUNDED PETRI NET, EVER.
@@ -41,9 +41,7 @@ def construct_reachability_graph(net, initial_marking):
     visited = []
     re_gr = ts.TransitionSystem()
     re_gr.states.add(ts.TransitionSystem.State(staterep(repr(initial_marking))))
-    for i in range(10000000):
-        if not active:
-            break
+    while active:
         curr_mark = active.pop(0)
         curr_state = next((state for state in re_gr.states if state.name == staterep(repr(curr_mark))), None)
         en_tr = petri.semantics.enabled_transitions(net, curr_mark)
@@ -53,7 +51,10 @@ def construct_reachability_graph(net, initial_marking):
             if next_state is None:
                 next_state = ts.TransitionSystem.State(staterep(repr(next_mark)))
                 re_gr.states.add(next_state)
-            utils.add_arc_from_to(repr(t), curr_state, next_state, re_gr)
+            if use_trans_name:
+                utils.add_arc_from_to(t.name, curr_state, next_state, re_gr)
+            else:
+                utils.add_arc_from_to(repr(t), curr_state, next_state, re_gr)
             # If the next marking hash is not in visited, if the next marking itself is not already in active
             # and if the next marking is different from the current one
             if hash(next_mark) not in visited and next((mark for mark in active if hash(mark) == hash(next_mark)),
