@@ -1,12 +1,10 @@
 from collections import Counter
 
 import numpy as np
-from numpy.linalg import svd
-from scipy.linalg import expm
 
 from pm4py.objects.petri.reachability_graph import construct_reachability_graph
 from pm4py.objects.stochastic_petri import tangible_reachability
-from pm4py.objects.conversion.dfg import factory as dfg_conv_factory
+from pm4py.objects.conversion.dfg import converter as dfg_converter
 from pm4py.objects.random_variables import exponential, random_variable
 
 
@@ -95,7 +93,7 @@ def get_tangible_reachability_and_q_matrix_from_dfg_performance(dfg_performance,
     """
     if parameters is None:
         parameters = {}
-    net, im, fm = dfg_conv_factory.apply(dfg_performance)
+    net, im, fm = dfg_converter.apply(dfg_performance)
     stochastic_map = {}
     for tr in net.transitions:
         if tr.label is None:
@@ -293,6 +291,8 @@ def transient_analysis_from_tangible_q_matrix_and_states_vector(tangible_reach_g
     transient_result
         Transient analysis result
     """
+    from scipy.linalg import expm
+
     transient_result = Counter()
     states = sorted(list(tangible_reach_graph.states), key=lambda x: x.name)
 
@@ -340,7 +340,7 @@ def nullspace(a_matrix, atol=1e-13, rtol=0):
         nullspace; each element in numpy.dot(A, ns) will be approximately
         zero.
     """
-
+    from numpy.linalg import svd
     a_matrix = np.atleast_2d(a_matrix)
     u, s, vh = svd(a_matrix)
     tol = max(atol, rtol * s[0])
