@@ -1,3 +1,5 @@
+import deprecation
+
 from pm4py.statistics.passed_time.log.versions import pre, post, prepost
 
 PRE = 'pre'
@@ -6,7 +8,8 @@ PREPOST = 'prepost'
 
 VERSIONS = {PRE: pre.apply, POST: post.apply, PREPOST: prepost.apply}
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use algorithm entrypoint instead')
 def apply(log, activity, variant=PRE, parameters=None):
     """
     Gets statistics on execution times of the paths to/from the activity
