@@ -1,4 +1,5 @@
 from pm4py.statistics.traces.pandas import case_statistics
+from pm4py.statistics.parameters import Parameters
 
 
 def get_variants_set(df, parameters=None):
@@ -11,7 +12,7 @@ def get_variants_set(df, parameters=None):
         Dataframe
     parameters
         Possible parameters of the algorithm, including:
-            activity_key -> Column that contains the activity
+            Parameters.ACTIVITY_KEY -> Column that contains the activity
 
     Returns
     --------------
