@@ -17,6 +17,3 @@ CASE_ATTRIBUTE_PREFIX = 'case:'
 
 PARAMETER_KEY_CASE_GLUE = 'case_id_glue'
 PARAMETER_KEY_CASE_ATTRIBUTE_PRFIX = 'case:'
-
-PARAMETER_TOKEN_REPLAY_VARIANT = "token_replay_variant"
-DEFAULT_TOKEN_REPLAY_VARIANT = "token_replay"
